@@ -1,6 +1,6 @@
 package P9Y::ProcessTable::Role::Table::PPT;
 
-our $VERSION = '1.05'; # VERSION
+our $VERSION = '1.06'; # VERSION
 
 #############################################################################
 # Modules
@@ -44,14 +44,15 @@ sub list {
 }
 
 sub fields {
-   return $pt->fields;
+   # sometimes an undef pops through
+   return grep { $_ } $pt->fields;
 }
 
 sub _process_hash {
    my ($self, $pid) = @_;
    my $process = first { $_->pid == $pid } @{ $pt->table };
    return unless $process;
-   return $self->_convert_process;
+   return $self->_convert_process($process);
 }
 
 sub _convert_process {
@@ -66,10 +67,7 @@ sub _convert_process {
 
    foreach my $key ( $self->fields ) {
       my $old = $stat_loc->{$key} || $key;
-
-      # Sigh, why give me a field I can't access?
-      my $item;
-      $item = $process->$old() if $process->can($old);
+      my $item = eval { $process->$old() };
 
       $hash->{$key} = $item if defined $item;
    }
